<template>
    <div class="app-container">
       <el-form :model="queryParams" ref="queryRef" :inline="true">
          <el-form-item label="费用项" prop="name">
             <el-input
                v-model="queryParams.name"
                placeholder="请输入费用项"
                clearable
                style="width: 200px"
                @keyup.enter="handleQuery"
             />
          </el-form-item>
          <el-form-item>
             <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
             <el-button icon="Refresh" @click="resetQuery">重置</el-button>
          </el-form-item>
       </el-form>
 
       <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
             <el-button
                type="primary"
                plain
                icon="Plus"
                @click="handleAdd"
             >新增</el-button>
          </el-col>
       </el-row>
       <!--表格及分页-->
       <el-table v-loading="loading" :data="tableData">
          <el-table-column
            v-for="(item, key, index) of tableHeader"
            :prop="key.toString()"
            :label="item"
            :key="index"
            align="center"
          >
        </el-table-column>
          <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
             <template #default="scope">
                <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)">修改</el-button>
                <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)">删除</el-button>
             </template>
          </el-table-column>
        </el-table>
        <pagination
          :total="pageParam.total"
          v-model:page="pageParam.page"
          v-model:limit="pageParam.limit"
          :page-sizes="[10,20,30]"
          @pagination="getList"
        />
       <!-- 添加或修改对话框 -->
       <el-dialog :title="title" v-model="open" append-to-body center>
          <el-form class="form-box" ref="formRef" :model="form" :rules="rules" label-width='auto'>
                   <el-form-item label="费用项" prop="feeItem">
                      <el-input v-model="form.feeItem" placeholder="请输入费用项"/>
                   </el-form-item>
                   <el-form-item label="所属用户分类"  prop="userClassify">
                        <el-select v-model="form.userClassify" placeholder="请输入所属用户分类">
                            <el-option 
                            v-for="(item,index) in userTypeList"
                            :label="item.name"
                            :value="item.id"
                            :key="index"
                            ></el-option>
                        </el-select>
                   </el-form-item>
                   <el-form-item label="费用类型" prop="feeType">
                      <el-input v-model="form.feeType" placeholder="请输入费用类型"/>
                   </el-form-item>
                   <el-form-item label="费用金额" prop="feeValue">
                      <el-input v-model="form.feeValue" placeholder="请输入费用金额" />
                   </el-form-item>
                    <el-form-item label="费用说明" prop="description">
                      <el-input v-model="form.description" placeholder="请输入说明" />
                   </el-form-item>
                   <el-form-item label="显示排序" prop="sort">
                      <el-input-number v-model="form.sort" controls-position="right" :min="1" />
                   </el-form-item>
          </el-form>
          <template #footer>
             <div class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
             </div>
          </template>
       </el-dialog>
    </div>
 </template>
 
 <script setup name="Menu">
 import  waterOtherFee from "@/api/configuration/waterOtherFee";
 import  userClassify from "@/api/configuration/userClassify";
 import setPostParams from "@/utils/searchParams.js";
 const { proxy } = getCurrentInstance();
 
/**
 * 搜索相关
 */
 /** 搜索按钮操作 */
 function handleQuery() {
   getList({keywords:queryParams.value.name,page:1})
 }
 
 /** 重置按钮操作 */
 function resetQuery() {
   proxy.resetForm("queryRef");
   handleQuery();
 }

 /**
  *  Table表格权限数据列表相关
  */

const pageParam = ref({
    total:0,
    limit:0,
    page:0,
})
const tableData = ref([]);
let  tableHeader = ref({
        feeItem: '费用项',
        className: '所属用户分类',
        feeTypeView: '费用类型',
        description: '费用说明',
        sort:'排序值',
   })
 /** 获取列表 */
 async function getList(val) {
      loading.value = true;

     let postParam = setPostParams(val)
      await waterOtherFee().search(postParam).then((res) =>{
        tableData.value = res.data.list
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
    loading.value = false;
 }
 
 /** 新增按钮操作 */
 async function handleAdd() {
   reset();
   open.value = true;
   title.value = "新增费用项";
 }
 
 /** 修改按钮操作 */
 async function handleUpdate(row) {
   reset();
   form.value = Object.assign({},row)
   open.value = true;
   title.value = "修改费用项";
 }

/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal.confirm('是否确认删除名称为"' + row.feeItem + '"的数据项?').then(function() {
    return waterOtherFee().remove(row.id);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

 /**
  *  新增/修改弹窗Form表单相关
  */
const open = ref(false);
const loading = ref(false);
const title = ref("");

const data = reactive({
form:{},
queryParams: {
    name: undefined,
},
rules: {
    feeItem: [{ required: true, message: "请输入费用项", trigger: "blur" }],
    userClassify: [{ required: true, message: "请选择用户分类", trigger: "blur" }],
    feeType: [{ required: true, message: "请选择费用类型", trigger: "blur" }],
    feeValue: [{ required: true, message: "请输入费用值", trigger: "blur" }],
    description: [{ required: true, message: "请输入费用说明", trigger: "blur" }],
},
});
const { queryParams, form, rules } = toRefs(data);
//获取用户分类列表
const userTypeList = ref()
const getUserType = async() =>{
   await userClassify().search({limit:10000,page:1}).then((res) =>{
   userTypeList.value = res.data.list
    })
}

 /** 提交按钮 */
 function submitForm() {
   proxy.$refs["formRef"].validate(valid => {
     if (valid) {
       if (form.value.id != undefined) {
         waterOtherFee().modify(form.value).then(res => {
           proxy.$modal.msgSuccess("修改成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("修改失败");
         });
       } else {
        waterOtherFee().create(form.value).then(res => {
           proxy.$modal.msgSuccess("新增成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("新增失败");
         });;
       }
     }
   });
 }

 /** 取消按钮 */
 function cancel() {
   open.value = false;
   reset();
 }
 
 /** 表单重置 */
 function reset() {
   form.value = {
        feeItem: '',
        userClassify: '',
        feeType:undefined,
        feeValue:undefined,
        description:undefined,
   };
   proxy.resetForm("formRef");
 }
 getUserType()
 getList();
 </script>
 